﻿* Encoding: UTF-8.
********************************************************************************************************************
This SPSS syntax file provides code with which to replicate the material provided in the chapters .                                   
********************************************************************************************************************

/* This section provides code for Chapter 5 .

/* This following code imports and shows some data management steps with the GSS 2014 data that .
/* include a question about attitudes toward gun laws The steps include (a) recode the variable .
/* gunlaw to 0,1, (b) recode the missing data, (c) assign new names and labels to the variables.
                                     
/*  2. Creation date: 20 Jan 2016 .            
/*  3. Last updated: 20 Jan 2016 . 
/*  4. Creator: Penelope, University of Ithica .
/*  5. Created for SPSS version 21 .

/* import the data .
get data / type=txt / file="[pathname]\GSS2014.txt" 
 / delimiters="," 
 / qualifier='"'  
 / firstcase=2 
 / variables=caseid F5.0 gunlaw F1.0 educ F2.0 sex F1.0 age F2.0 .

/* rename variables .
rename variables gunlaw = GunPermit .
rename variables educ = education .
rename variables sex = female .

/* label variables .
variable labels
 GunPermit 'Favor police permits for guns' /
 education 'Years of formal education' /
 female 'Sex of respondent' /
 age 'Age of respondent' .

/* recode variables .
recode GunPermit (0=8) .
missing values GunPermit (8,9) .
recode GunPermit (2=0) .
missing values education (97,98,99) .
recode female (1=0)(2=1) .
missing values age (0,98,99) .

/* assign value labels .
value labels GunPermit 0  'oppose' 1 'favor' /
          female 0 'male' 1 'female'.

/* check the results .
frequencies
 / variables = GunPermit  female.

descriptives 
 / variables = education age.


*****************************************************************************
This section produces the information for the tables in Chapter 9 
and provides code for several of the graphics in Chapter 10         
*****************************************************************************

/* Chapter 9 .

/* Table of mean education by gun permit and sex .
means tables = education by GunPermit.

/* means by sex .
means tables = education by GunPermit by female.

/* Create and label the categorical education variable .
recode education (12=2) (0 thru 11=1) (13 thru 15=3) (16 thru 20=4) into educCat .
variable labels educCat 'Education categorized' .
value labels educCat 1  'Not HS graduate' 2 'High school graduate' 3 'Attended college' 4 'College graduate' .
execute .

/* Table of mean favor of gun permits by education and sex .
means tables = GunPermit by educCat .
means tables = GunPermit by educCat by female .


/* Chapter 10 .

/* Figure 10.6 .
/* Pie chart - education categories .
GGRAPH
  /GRAPHDATASET NAME="graphdataset" VARIABLES=educCat COUNT()[name="COUNT"] MISSING=LISTWISE
    REPORTMISSING=NO
  /GRAPHSPEC SOURCE=INLINE
   TEMPLATE=[
    "C:\Program Files\IBM\SPSS\Statistics\23\Looks\GrayScale.sgt"
    "C:\Program Files\IBM\SPSS\Statistics\23\Looks\APA_Styles.sgt"].
BEGIN GPL
  SOURCE: s=userSource(id("graphdataset"))
  DATA: educCat=col(source(s), name("educCat"), unit.category())
  DATA: COUNT=col(source(s), name("COUNT"))
  COORD: polar.theta(startAngle(0))
  GUIDE: axis(dim(1), null())
  GUIDE: legend(aesthetic(aesthetic.texture.pattern.interior), null())
  GUIDE: text.title(label("Figure 10.6. Pie chart example: Education categories"))
  SCALE: linear(dim(1), dataMinimum(), dataMaximum())
  SCALE: cat(aesthetic(aesthetic.texture.pattern.interior), include("4.00", "2.00", "3.00", 
    "1.00"), sort.values("4.00", "2.00", "3.00", "1.00"))
  ELEMENT: interval.stack(position(summary.percent(COUNT))), texture.pattern.interior(educCat))
END GPL.

/* Figure 10.8 .
/* Horizontal bar chart - education categories .
GGRAPH 
  /GRAPHDATASET NAME="graphdataset" VARIABLES=educCat COUNT()[name="COUNT"] MISSING=LISTWISE 
    REPORTMISSING=NO 
  /GRAPHSPEC SOURCE=INLINE 
   TEMPLATE=[ 
  "C:\Program Files\IBM\SPSS\Statistics\23\Looks\GrayScale.sgt"   
  "C:\Program Files\IBM\SPSS\Statistics\23\Looks\APA_Styles.sgt"]. 
BEGIN GPL 
  SOURCE: s=userSource(id("graphdataset")) 
  DATA: educCat=col(source(s), name("educCat"), unit.category()) 
  DATA: COUNT=col(source(s), name("COUNT")) 
  GUIDE: axis(dim(1), label("Education categorized")) 
  GUIDE: axis(dim(2), label("Count")) 
  GUIDE: text.title(label("Horizontal bar graph of [variable name]")) 
  SCALE: cat(dim(1), include("4.00", "3.00", "2.00", "1.00"), sort.values("1.00", "3.00", "2.00", "4.00")) 
  SCALE: linear(dim(2), include(0)) 
  COORD: transpose()
  ELEMENT: interval(position(educCat*COUNT), shape.interior(shape.square)) 
END GPL.

/* Figure 10.9 . 
/* Dot plot - education categories .
GGRAPH 
  /GRAPHDATASET NAME="graphdataset" VARIABLES=educCat VALIDN(CASEID)[name="VALIDN_CASEID"] 
    MISSING=LISTWISE REPORTMISSING=NO 
  /GRAPHSPEC SOURCE=INLINE
  TEMPLATE=[ 
  "C:\Program Files\IBM\SPSS\Statistics\23\Looks\GrayScale.sgt"   
  "C:\Program Files\IBM\SPSS\Statistics\23\Looks\APA_Styles.sgt"]. 
BEGIN GPL 
  SOURCE: s=userSource(id("graphdataset")) 
  DATA: educCat=col(source(s), name("educCat"), unit.category()) 
  DATA: VALIDN_CASEID=col(source(s), name("VALIDN_CASEID")) 
  COORD: rect(dim(1,2), transpose()) 
  GUIDE: axis(dim(1), gridlines())
  GUIDE: axis(dim(2), label("Number in each education category")) 
  GUIDE: text.title(label("Figure 10.9. Dot plot of education categories")) 
  SCALE: cat(dim(1), include("1.00", "3.00", "2.00", "4.00"), sort.values("1.00", "3.00", 
    "2.00", "4.00")) 
  SCALE: linear(dim(2), include(0)) 
  ELEMENT: point(position(educCat*VALIDN_CASEID), size(size.small), shape.interior(shape.circle)) 
END GPL.

/* Figure 10.11 .
/* Dot plot - proportion favoring gun permits .
GGRAPH
  /GRAPHDATASET NAME="graphdataset" VARIABLES=educCat MEAN(GunPermit)[name="MEAN_GunPermit"] 
    MISSING=LISTWISE REPORTMISSING=NO
  /GRAPHSPEC SOURCE=INLINE
 TEMPLATE=[ 
  "C:\Program Files\IBM\SPSS\Statistics\23\Looks\GrayScale.sgt"   
  "C:\Program Files\IBM\SPSS\Statistics\23\Looks\APA_Styles.sgt"]. 
BEGIN GPL
  SOURCE: s=userSource(id("graphdataset"))
  DATA: educCat=col(source(s), name("educCat"), unit.category())
  DATA: MEAN_GunPermit=col(source(s), name("MEAN_GunPermit"))
  COORD: rect(dim(1,2), transpose())
  GUIDE: axis(dim(1), label(""), gridlines())
  GUIDE: axis(dim(2), label("Proportion favoring gun permits"), delta(0.2))
  GUIDE: text.title(label("Figure 10.11. Proportion in favor of gun permits")) 
  GUIDE: text.subsubtitle(label("by level of education"))
  SCALE: cat(dim(1), include("1.00", "2.00", "3.00", "4.00"), sort.values("2.00", "3.00", "1.00", "4.00"))
  SCALE: linear(dim(2), include(0, 0.2, 0.4, 0.6, 0.8))
  ELEMENT: point(position(educCat*MEAN_GunPermit))
END GPL.

/* Figure 10.12 .
/* Dot plot by education and sex .
GGRAPH
  /GRAPHDATASET NAME="graphdataset" VARIABLES=educCat MEAN(GunPermit)[name="MEAN_GunPermit"] female 
    MISSING=LISTWISE REPORTMISSING=NO
  /GRAPHSPEC SOURCE=INLINE
 TEMPLATE=[ 
  "C:\Program Files\IBM\SPSS\Statistics\23\Looks\GrayScale.sgt"   
  "C:\Program Files\IBM\SPSS\Statistics\23\Looks\APA_Styles.sgt"]. 
BEGIN GPL
  SOURCE: s=userSource(id("graphdataset"))
  DATA: educCat=col(source(s), name("educCat"), unit.category())
  DATA: MEAN_GunPermit=col(source(s), name("MEAN_GunPermit"))
  DATA: female=col(source(s), name("female"), unit.category())
  COORD: rect(dim(1,2), transpose())
  GUIDE: axis(dim(1), label(""), gridlines())
  GUIDE: axis(dim(2), label("Proportion favoring gun permits"))
  GUIDE: legend(aesthetic(aesthetic.texture.pattern.interior), null())
  GUIDE: text.title(label("Figure 10.12. Dot plot of proportion who favor gun permits,"))
  GUIDE: text.subtitle(label("by education and sex"))
  SCALE: cat(dim(1), include("1.00", "2.00", "3.00", "4.00"), sort.values("3.00", "1.00", "2.00", "4.00"))
  SCALE: linear(dim(2), include(0))
  SCALE: cat(aesthetic(aesthetic.shape.interior), include("0", "1"))
  ELEMENT: point(position(educCat*MEAN_GunPermit), label(female))
END GPL.

/* Figure 10.13 .
/* Line graph of favor gun permits by education categories .
GGRAPH
  /GRAPHDATASET NAME="graphdataset" VARIABLES=educCat MEAN(GunPermit)[name="MEAN_GunPermit"] female 
    MISSING=LISTWISE REPORTMISSING=NO
  /GRAPHSPEC SOURCE=INLINE
 TEMPLATE=[ 
  "C:\Program Files\IBM\SPSS\Statistics\23\Looks\GrayScale.sgt"   
  "C:\Program Files\IBM\SPSS\Statistics\23\Looks\APA_Styles.sgt"]. 
BEGIN GPL
  SOURCE: s=userSource(id("graphdataset"))
  DATA: educCat=col(source(s), name("educCat"), unit.category())
  DATA: MEAN_GunPermit=col(source(s), name("MEAN_GunPermit"))
  DATA: female=col(source(s), name("female"), unit.category())
  GUIDE: axis(dim(1), label(""))
  GUIDE: axis(dim(2), label("Proportion favoring gun permits"))
  GUIDE: legend(aesthetic(aesthetic.texture.pattern.interior), null())
  GUIDE: text.title(label("Figure 10.13. Proportion in favor of gun permits,"))
  GUIDE: text.subtitle(label("by education categories and sex"))
  SCALE: cat(dim(1), include("1.00", "2.00", "3.00", "4.00"))
  SCALE: linear(dim(2), min(0.5))
  ELEMENT: line(position(educCat*MEAN_GunPermit), split(female), missing.wings(), label(female))
END GPL.

/* Figure 10.14 .
/* Line graph of favor gun permits by continous education .
GGRAPH 
  /GRAPHDATASET NAME="graphdataset" VARIABLES=education GunPermit female MISSING=LISTWISE 
    REPORTMISSING=NO 
  /GRAPHSPEC SOURCE=INLINE
 TEMPLATE=[ 
  "C:\Program Files\IBM\SPSS\Statistics\23\Looks\GrayScale.sgt"   
  "C:\Program Files\IBM\SPSS\Statistics\23\Looks\APA_Styles.sgt"].  
BEGIN GPL 
  SOURCE: s=userSource(id("graphdataset")) 
  DATA: education=col(source(s), name("education"), unit.category()) 
  DATA: GunPermit=col(source(s), name("GunPermit")) 
  DATA: female=col(source(s), name("female"), unit.category()) 
  GUIDE: axis(dim(1), label("Years of formal education")) 
  GUIDE: axis(dim(2), label("Proportion in favor of gun permits")) 
  GUIDE: legend(aesthetic(aesthetic.texture.pattern.interior), null())
  GUIDE: text.title(label("Figure 10.14. Linear fit line sof association between favoring"))
  GUIDE: text.subtitle(label("gun permits and education (in years), by sex"))
  SCALE: linear(dim(2), min(0.5)) 
  ELEMENT: line(position(smooth.linear(education*GunPermit))), split(female), label(female))
END GPL.

/* Lowess smoother depiction of favoring gun permits by education .
GGRAPH 
  /GRAPHDATASET NAME="graphdataset" VARIABLES=education GunPermit female MISSING=LISTWISE 
    REPORTMISSING=NO 
  /GRAPHSPEC SOURCE=INLINE
 TEMPLATE=[ 
  "C:\Program Files\IBM\SPSS\Statistics\23\Looks\GrayScale.sgt"   
  "C:\Program Files\IBM\SPSS\Statistics\23\Looks\APA_Styles.sgt"].  
BEGIN GPL 
  SOURCE: s=userSource(id("graphdataset")) 
  DATA: education=col(source(s), name("education"), unit.category()) 
  DATA: GunPermit=col(source(s), name("GunPermit")) 
  DATA: female=col(source(s), name("female"), unit.category()) 
  GUIDE: axis(dim(1), label("Years of formal education")) 
  GUIDE: axis(dim(2), label("Proportion in favor of gun permits")) 
  GUIDE: legend(aesthetic(aesthetic.texture.pattern.interior), null())
  GUIDE: text.title(label("Figure 10.14. Lowess fit lines of association between favoring"))
  GUIDE: text.subtitle(label("gun permits and education (in years), by sex"))
  SCALE: linear(dim(2), min(0.5)) 
  ELEMENT: line(position(smooth.loess(education*GunPermit))), split(female), label(female))
END GPL.

/* Close the GSS2014 data set .
dataset close * .

/* Import the violent crime data .
get data / type=txt / file="[pathname]\ViolentCrimeTrends.csv"  
 / delimiters="," 
 / qualifier='"'  
 / firstcase=2 
 / variables = State A11 StateAbbrev A2 fipscode F2.0 Year F4.0 ViolentCrimeRate F6.1 . 

/* Temporarily select only the three states for the first line graph . 
temp. 
select if (fipscode=6|fipscode=21|fipscode=56).

/* Figure 10.15 .
/* Line graph of trends in violent crimes in three states  .
GGRAPH
  /GRAPHDATASET NAME="graphdataset" VARIABLES=Year ViolentCrimeRate StateAbbrev MISSING=LISTWISE 
    REPORTMISSING=NO
  /GRAPHSPEC SOURCE=INLINE
 TEMPLATE=[ 
  "C:\Program Files\IBM\SPSS\Statistics\23\Looks\GrayScale.sgt"   
  "C:\Program Files\IBM\SPSS\Statistics\23\Looks\APA_Styles.sgt"].
BEGIN GPL
  SOURCE: s=userSource(id("graphdataset"))
  DATA: Year=col(source(s), name("Year"))
  DATA: ViolentCrimeRate=col(source(s), name("ViolentCrimeRate"))
  DATA: StateAbbrev=col(source(s), name("StateAbbrev"), unit.category())
  GUIDE: axis(dim(1), label("Year"))
  GUIDE: axis(dim(2), label("Violent crimes per 100,000"))
  GUIDE: legend(aesthetic(aesthetic.shape.interior), null())
  GUIDE: text.title(label("Figure 10.15. Violent crime rates, 1990-2012"))
  GUIDE: text.subtitle(label("California, Kentucky, and Wyoming"))
  SCALE: linear(dim(1), min(1990), max(2012))
  ELEMENT: line(position(Year*ViolentCrimeRate), shape.interior(StateAbbrev), label(StateAbbrev), missing.wings())
END GPL.

/* Close the violent crimes data set .
dataset close  * .


/* import the endangered species data .
get data  / type=txt / file="[pathname]\EndangeredSpecies.csv" 
 / delimiters="," 
 / qualifier='"' 
 / firstcase=2 
 / variables = Nation A19 NationNumber F2.0 Population F9.0 EnergyConsumption F16.14 CO2Emissions F16.14 
               EndangerRate F17.15 IncomeLevel F1.0 GDP F16.14 . 

/* Label the variables and the country codes .
/* Create variables labels .
variable labels 
  Nation "Name of Nation" /
  NationNumber "Nation code" /
  EnergyConsumption "Energy consumption per capita" /
  CO2Emissions "CO2 emissions per capita" /
  EndangerRate "Rate of endangered species" /
  IncomeLevel "Income level, 0=low, 1=high" /
  GDP "Gross domestic product per capita" .

/* create value labels for the nations based on NationNumber .
value labels NationNumber 1 "AO" 2 "BD" 3 "BZ" 4 "BJ" 5 "BT" 6 "BO" 7 "BW"  
    8 "BF" 9 "BI" 10 "CM" 11 "CF" 12 "TD" 13 "CH"   
    14 "CO" 15 "CG" 16 "CR" 17 "CI" 18 "DO" 19 "EC"  
    20 "SV" 21 "CQ" 22 "ET" 23 "FJ" 24 "GA" 25 "GM"  
    26 "GH" 27 "GT" 28 "GN" 29 "GW" 30 "GY" 31 "HT"  
    32 "HN" 33 "IS" 34 "JM" 35 "LA" 36 "LR"  
    37 "MG" 38 "MW" 39 "ML" 40 "MR" 41 "MU" 42 "MN" 
   	43 "MA" 44 "MZ" 45 "MM" 46 "NP" 47 "NI" 48 "NE"  
    49 "OM" 50 "PK" 51 "PA" 52 "PG" 53 "PY" 54 "RW" 55 "SN" 
    56 "SL" 57 "SB" 58 "SO" 59 "LK" 60 "SD" 61 "SR" 
    62 "SZ" 63 "SY" 64 "TZ" 65 "TG" 66 "TT" 67 "TN"  
    68 "UG" 69 "VN" 70 "CD" 71 "ZM" 72 "ZW" .

/* Figure 10.17 .
/* Scatterplot of CO2 emissions and endangered species .
formats EndangerRate CO2Emissions (f2.0) .
GGRAPH
  /GRAPHDATASET NAME="graphdataset" VARIABLES=CO2Emissions EndangerRate MISSING=LISTWISE 
    REPORTMISSING=NO
  /GRAPHSPEC SOURCE=INLINE
 TEMPLATE=[ 
  "C:\Program Files\IBM\SPSS\Statistics\23\Looks\GrayScale.sgt"   
  "C:\Program Files\IBM\SPSS\Statistics\23\Looks\APA_Styles.sgt"].
BEGIN GPL
  SOURCE: s=userSource(id("graphdataset"))
  DATA: CO2Emissions=col(source(s), name("CO2Emissions"))
  DATA: EndangerRate=col(source(s), name("EndangerRate"))
  GUIDE: axis(dim(1), delta(2), label("CO2 emissions per capita"))
  GUIDE: axis(dim(2), delta(1), label("Rate of endangered species"))
  GUIDE: text.title(label("Figure 10.17. CO2 Emissions & Endangered Species,"))
  GUIDE: text.subtitle(label("by Country"))
  GUIDE: text.footnote(label("Source: World Bank & IUCN Red List, 2006."))
  SCALE: linear(dim(1), min(4), max(12))
  SCALE: linear(dim(2), min(0), max(3))
  ELEMENT: point(position(CO2Emissions*EndangerRate))
END GPL.

/* Figure 10.18 .
/* Scatterplot of CO2 emissions and endangered species .
/* with nation abbreviation for markers .
formats EndangerRate CO2Emissions (f2.0) .
GGRAPH
  /GRAPHDATASET NAME="graphdataset" VARIABLES=CO2Emissions EndangerRate NationNumber 
    MISSING=LISTWISE REPORTMISSING=NO
  /GRAPHSPEC SOURCE=INLINE.
BEGIN GPL
  SOURCE: s=userSource(id("graphdataset"))
  DATA: CO2Emissions=col(source(s), name("CO2Emissions"))
  DATA: EndangerRate=col(source(s), name("EndangerRate"))
  DATA: NationNumber=col(source(s), name("NationNumber"))
  GUIDE: axis(dim(1), label("CO2 emissions per capita"))
  GUIDE: axis(dim(2), label("Rate of endangered species"))
  GUIDE: text.title(label("Figure 10.18. CO2 Emissions & Endangered Species,"))
  GUIDE: text.subtitle(label("by Country"))
  GUIDE: text.footnote(label("Source: World Bank and IUCN Red List, 2006."))
  SCALE: linear(dim(1), min(4), max(12))
  SCALE: linear(dim(2), min(0), max(3))
  ELEMENT: point(position(CO2Emissions*EndangerRate), label(NationNumber))
END GPL.

/* Figure 10.19 .
/* Scatterplot of CO2 emissions and endangered species .
/* with line plot using a linear fit  .
formats EndangerRate CO2Emissions (f2.0) .
GGRAPH
  /GRAPHDATASET NAME="graphdataset" VARIABLES=CO2Emissions EndangerRate MISSING=LISTWISE 
    REPORTMISSING=NO
  /GRAPHSPEC SOURCE=INLINE
 TEMPLATE=[ 
  "C:\Program Files\IBM\SPSS\Statistics\23\Looks\GrayScale.sgt"   
  "C:\Program Files\IBM\SPSS\Statistics\23\Looks\APA_Styles.sgt"].
BEGIN GPL
  SOURCE: s=userSource(id("graphdataset"))
  DATA: CO2Emissions=col(source(s), name("CO2Emissions"))
  DATA: EndangerRate=col(source(s), name("EndangerRate"))
  GUIDE: axis(dim(1), delta(2), label("CO2 emissions per capita"))
  GUIDE: axis(dim(2), delta(1), label("Rate of endangered species"))
  GUIDE: text.title(label("Figure 10.19. CO2 Emissions & Endangered Species,"))
  GUIDE: text.subtitle(label("by Country"))
  GUIDE: text.footnote(label("Source: World Bank & IUCN Red List, 2006."))
  SCALE: linear(dim(1), min(4), max(12))
  SCALE: linear(dim(2), min(0), max(3))
  ELEMENT: point(position(CO2Emissions*EndangerRate))
  ELEMENT: line(position(smooth.linear(CO2Emissions*EndangerRate)))
END GPL.

/* Figure 10.20 .
/* Scatterplot of CO2 emissions and endangered species by income level .
formats EndangerRate CO2Emissions (f2.0) .
GGRAPH
  /GRAPHDATASET NAME="graphdataset" VARIABLES=CO2Emissions EndangerRate IncomeLevel MISSING=LISTWISE 
    REPORTMISSING=NO
  /GRAPHSPEC SOURCE=INLINE
 TEMPLATE=[ 
  "C:\Program Files\IBM\SPSS\Statistics\23\Looks\GrayScale.sgt"   
  "C:\Program Files\IBM\SPSS\Statistics\23\Looks\APA_Styles.sgt"].
BEGIN GPL
  SOURCE: s=userSource(id("graphdataset"))
  DATA: CO2Emissions=col(source(s), name("CO2Emissions"))
  DATA: EndangerRate=col(source(s), name("EndangerRate"))
  DATA: IncomeLevel=col(source(s), name("IncomeLevel"), unit.category())
  GUIDE: axis(dim(1), label("CO2 emissions per capita"))
  GUIDE: axis(dim(2), label("Rate of endangered species"))
  GUIDE: text.title(label("Figure 10.20. CO2 Emissions & Endangered Species,"))
  GUIDE: text.subtitle(label("by Country's Income Level"))
  GUIDE: text.footnote(label("Source: World Bank & IUCN Red List, 2006."))
  GUIDE: legend(aesthetic(aesthetic.texture.pattern.interior), null())
  SCALE: linear(dim(1), min(4), max(12))
  SCALE: linear(dim(2), min(0), max(3))
  ELEMENT: point(position(CO2Emissions*EndangerRate), shape.interior(IncomeLevel))
END GPL.

/* Figure 10.21 .
/* Scatterplot of CO2 emissions and endangered species by income level .
formats EndangerRate CO2Emissions (f2.0) .
GGRAPH
  /GRAPHDATASET NAME="graphdataset" VARIABLES=CO2Emissions EndangerRate IncomeLevel MISSING=LISTWISE 
    REPORTMISSING=NO
  /GRAPHSPEC SOURCE=INLINE
 TEMPLATE=[ 
  "C:\Program Files\IBM\SPSS\Statistics\23\Looks\GrayScale.sgt"   
  "C:\Program Files\IBM\SPSS\Statistics\23\Looks\APA_Styles.sgt"].
BEGIN GPL
  SOURCE: s=userSource(id("graphdataset"))
  DATA: CO2Emissions=col(source(s), name("CO2Emissions"))
  DATA: EndangerRate=col(source(s), name("EndangerRate"))
  DATA: IncomeLevel=col(source(s), name("IncomeLevel"), unit.category())
  GUIDE: axis(dim(1), label("CO2 emissions per capita"))
  GUIDE: axis(dim(2), label("Rate of endangered species"))
  GUIDE: text.title(label("Figure 10.21. CO2 Emissions & Endangered Species,"))
  GUIDE: text.subtitle(label("by Country's Income Level"))
  GUIDE: text.footnote(label("Source: World Bank & IUCN Red List, 2006."))
  GUIDE: legend(aesthetic(aesthetic.texture.pattern.interior), null())
  GUIDE: legend(aesthetic(aesthetic.shape.interior), null())
  SCALE: linear(dim(1), min(4), max(12))
  SCALE: linear(dim(2), min(0), max(3))
  ELEMENT: point(position(CO2Emissions*EndangerRate), shape.interior(IncomeLevel))
  ELEMENT: line(position(smooth.linear(CO2Emissions*EndangerRate)), shape.interior(IncomeLevel), label(IncomeLevel))
END GPL.

